ScenEdit_AddSide({Name="Player"})
ScenEdit_AddSide({Name="OPFOR"})
ScenEdit_SetSidePosture("Player", "OPFOR", "H")
ScenEdit_SetSidePosture("OPFOR", "Player", "H")

EnemyEMCON = string.gsub(EnemyEMCON,"_","=")
EnemyEMCON = string.gsub(EnemyEMCON,"|",";")

ROETable={
	{description='WEAPONS_FREE', value=0},
	{description='WEAPONS_TIGHT', value=1},
	{description='WEAPONS_HOLD', value=2},
}

for k,v in ipairs (ROETable) do
	if v.description == EnemyROE then ROEValue = v.value end
	
end

function ReturnClassAndLoadout(targetString,delimiter)
	local delimiter = string.find(targetString,delimiter)
	local extractedClass = string.sub(targetString,1,delimiter-1)
	local extractedLoadout = string.sub(targetString,delimiter+1,string.len(targetString))
	return {dbid = extractedClass,loadout = extractedLoadout}
end

function AddMultipleAircraft(quantity,callsign,side,dbid,loadout,latitude,longitude,heading,altitude)
	local circle = World_GetCircleFromPoint({latitude=latitude,longitude=longitude,radius=0.5,numpoints = 72})
	local addedAircraftTable = {}
	if heading == nil then heading = 0 end
	if altitude== nil then altitude = 10000.0 end
	if quantity < 1 then quantity = 1 end
		for i = 1, quantity do
			if i > 1 then
				position = circle[i-1]
			else
				position = {latitude=latitude,longitude=longitude}
			end
			local unit = ScenEdit_AddUnit({type='Aircraft',side=side,dbid=dbid,name=callsign..' #'..i,loadoutid=loadout,latitude=position.latitude,longitude=position.longitude,heading=heading,altitude=altitude}) --default alt of 36kft; undefined altitude will throw an error; also seems to only recognise the integer and not the decimal so the underlying function may need tweaking
			table.insert(addedAircraftTable,unit)
		end	
	return addedAircraftTable
end

--ScenEdit_SetTime({ }) --placeholder/reminder to add set time once function is finalised
--latitude='29.3973255157471', longitude='47.3163108825684'

--Change lat and lon below so scenario loc.
ScenEdit_AddReferencePoint({side="OPFOR", name="Centrepoint", lat=29.3973255157471, lon=47.3163108825684, highlighted=false})
centrePoint = ScenEdit_GetReferencePoint({side='OPFOR',name='Centrepoint'}) --tied to a reference point so it's easy to move wherever you like

playerRadial = math.random(0,359)
splitDistance = StartDistance / 2
enemyRadial = (playerRadial + 180)%360

playerStartPosition = World_GetPointFromBearing({
	latitude=centrePoint.latitude,
	longitude=centrePoint.longitude,
	bearing=playerRadial,
	distance=splitDistance})
	
enemyStartPosition = World_GetPointFromBearing({
	latitude=centrePoint.latitude,
	longitude=centrePoint.longitude,
	bearing=enemyRadial,
	distance=splitDistance})

playerAircraft = ReturnClassAndLoadout(OwnAircraftClassAndLoadout,'_')
enemyAircraft = ReturnClassAndLoadout(EnemyAircraftClassAndLoadout,'_')
playerCallsign = 'Blue'
enemyCallsign = 'Red'

AddMultipleAircraft(
	OwnAircraftQuantity,
	playerCallsign,
	'Player',
	playerAircraft.dbid,
	playerAircraft.loadout,
	playerStartPosition.latitude,
	playerStartPosition.longitude,
	enemyRadial,
	StartAltitude
)

enemyAircraftList = AddMultipleAircraft(
	EnemyAircraftQuantity,
	enemyCallsign,
	'OPFOR',
	enemyAircraft.dbid,
	enemyAircraft.loadout,
	enemyStartPosition.latitude,
	enemyStartPosition.longitude,
	playerRadial,
	EnemyAltitude
)

--the weather values below are just examples, temperature could probably do with some adjustment
weatherTable = {
	{key=0, rainfall =0, undercloud=0, seastate =0, temperature=15},
	{key=1, rainfall =0, undercloud=0.1, seastate =1, temperature=14},
	{key=2, rainfall =0, undercloud=0.2, seastate =2, temperature=13},
	{key=3, rainfall =0, undercloud=0.3, seastate =3, temperature=12},
	{key=4, rainfall =0, undercloud=0.4, seastate =4, temperature=11},
	{key=5, rainfall =10, undercloud=0.5, seastate =5, temperature=10},
	{key=6, rainfall =25, undercloud=0.6, seastate =6, temperature=9},
	{key=7, rainfall =40, undercloud=0.7, seastate =7, temperature=8},
	{key=8, rainfall =55, undercloud=0.8, seastate =8, temperature=7},
	{key=9, rainfall =70, undercloud=0.9, seastate =9, temperature=6},
	{key=10, rainfall =100, undercloud=1, seastate =9, temperature=5},
}

for k,v in ipairs (weatherTable) do
	if v.key == Weather then
	ScenEdit_SetWeather(v.temperature, v.rainfall, v.undercloud, v.seastate)
    end
end

--29.167nm is a 5 minute stretch at 350kt; this will add one point in front and behind the Red aircraft so they start in the middle of their patrol zone
missionPatrolPoints = {
	World_GetPointFromBearing({latitude=enemyStartPosition.latitude,longitude=enemyStartPosition.longitude,distance=29.167/2,bearing=playerRadial}),
	World_GetPointFromBearing({latitude=enemyStartPosition.latitude,longitude=enemyStartPosition.longitude,distance=29.167/2,bearing=enemyRadial}),
}

missionReferencePoints={}

for k,v in ipairs (missionPatrolPoints) do
	local referencePoint = ScenEdit_AddReferencePoint({side='OPFOR',name='Ref '..k,latitude=v.latitude,longitude=v.longitude})
	table.insert(missionReferencePoints,referencePoint.guid)
end

local mission = ScenEdit_AddMission ('OPFOR', 'OPFOR Mission', 'Patrol', {type='AAW',zone=missionReferencePoints})

for k,v in ipairs (enemyAircraftList) do
	ScenEdit_AssignUnitToMission(v.guid,mission.guid)
end

ScenEdit_SetDoctrine({mission=mission.name,side=mission.side},{weapon_control_status_air=0})
ScenEdit_SetEMCON("Mission",mission.name,EnemyEMCON)
ScenEdit_SetTime({Date="2.1.1991", Time="12.46.23"})